@@ -352,6 +352,10 @@ class dyagram:
 
         device_diffs = {}
 
+        elem_changed = {
+            "routes": []}  # this keeps up with "changes" when converting to removed/add for routes,
+                           # this is due to deeper dictionary items
+
         diff_resp = DeepDiff(previous_state, current_state, ignore_order=True)
 
         if not diff_resp:
@@ -381,8 +385,6 @@ class dyagram:
                 if category == "dynamic_routing_neighbors":
                     if 'eigrp' in diff:
                         routing_protocol = "EIGRP"
-
-
                     elif 'ospf' in diff:
                         routing_protocol = "OSPF"
                     elif 'bgp' in diff:
@@ -397,7 +399,7 @@ class dyagram:
                         device_diffs[s['devices'][device_elem]['inventory_ip']]["added"].append(
                             f"{routing_protocol} Neighbor {diff_resp[k][diff]['new_value']}")
 
-                if category == "layer2":
+                elif category == "layer2":
                     if diff_type != "changed":
                         device_diffs[s['devices'][device_elem]['inventory_ip']][diff_type].append(
                             f"LLDP Neighbor {diff_resp[k][diff]['hostname']} (Chassis ID: {diff_resp[k][diff]['chassis_id']})")
@@ -409,6 +411,39 @@ class dyagram:
                             f"LLDP Neighbor {s['devices'][device_elem][category]['neighbors'][neigh_elem]['hostname']}: {neigh_property}: "
                             f"NEW VALUE: {diff_resp[k][diff]['new_value']}, OLD VALUE: {diff_resp[k][diff]['old_value']}")
 
+                elif category == "routes":
+
+                    if diff_type != "changed":
+
+                        device_diffs[s['devices'][device_elem]['inventory_ip']][diff_type].append(
+
+                            f"Route {diff_resp[k][diff]['network']}/{diff_resp[k][diff]['mask']} {diff_resp[k][diff]['next_hop']}")
+
+                    else:
+
+                        resp = re.search("\['routes'\]\[(\d+)\]\['(.*)'\]", diff)
+
+                        route_elem = int(resp.group(1))
+
+                        if route_elem not in elem_changed['routes']:
+                            elem_changed['routes'].append(route_elem)
+
+                            device_diffs[s['devices'][device_elem]['inventory_ip']]["removed"].append(
+                                f"Route {s['devices'][device_elem][category][route_elem]['network']}/"
+
+                                f"{previous_state['devices'][device_elem][category][route_elem]['mask']} "
+
+                                f"{previous_state['devices'][device_elem][category][route_elem]['next_hop']}")
+
+                            device_diffs[s['devices'][device_elem]['inventory_ip']]["added"].append(
+
+                                f"Route {s['devices'][device_elem][category][route_elem]['network']}/"
+
+                                f"{current_state['devices'][device_elem][category][route_elem]['mask']} "
+
+                                f"{current_state['devices'][device_elem][category][route_elem]['next_hop']}")
+
+
         return device_diffs
 
     def get_device_type(self, device):
